# Generated by Django 2.0.2 on 2018-02-21 16:38

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DemoModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
            ],
        ),
        migrations.CreateModel(
            name='DemoModelField',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('char', models.CharField(max_length=255)),
                ('integer', models.IntegerField()),
                ('logic', models.BooleanField(default=False)),
                ('null_logic', models.NullBooleanField(default=None)),
                ('date', models.DateField()),
                ('datetime', models.DateTimeField()),
                ('time', models.TimeField()),
                ('decimal', models.DecimalField(decimal_places=3, max_digits=10)),
                ('email', models.EmailField(max_length=254)),
                ('float', models.FloatField()),
                ('bigint', models.BigIntegerField()),
                ('generic_ip', models.GenericIPAddressField()),
                ('url', models.URLField()),
                ('text', models.TextField()),
                ('unique', models.CharField(max_length=255, unique=True)),
                ('nullable', models.CharField(max_length=255, null=True)),
                ('blank', models.CharField(blank=True, max_length=255, null=True)),
                ('not_editable', models.CharField(blank=True, editable=False, max_length=255, null=True)),
                ('choices', models.IntegerField(choices=[(1, 'Choice 1'), (2, 'Choice 2'), (3, 'Choice 3')])),
            ],
        ),
        migrations.CreateModel(
            name='DemoRelated',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
            ],
        ),
        migrations.AddField(
            model_name='demomodel',
            name='demo_related',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='demoapp.DemoRelated'),
        ),
        migrations.CreateModel(
            name='DemoModel_IntersectionFieldListFilter',
            fields=[
            ],
            options={
                'verbose_name': 'IntersectionFieldListFilter',
                'proxy': True,
                'indexes': [],
            },
            bases=('demoapp.demomodel',),
        ),
        migrations.CreateModel(
            name='DemoModel_RelatedFieldCheckBoxFilter',
            fields=[
            ],
            options={
                'verbose_name': 'RelatedFieldCheckBoxFilter',
                'proxy': True,
                'indexes': [],
            },
            bases=('demoapp.demomodel',),
        ),
        migrations.CreateModel(
            name='DemoModel_RelatedFieldRadioFilter',
            fields=[
            ],
            options={
                'verbose_name': 'RelatedFieldRadioFilter',
                'proxy': True,
                'indexes': [],
            },
            bases=('demoapp.demomodel',),
        ),
        migrations.CreateModel(
            name='DemoModel_UnionFieldListFilter',
            fields=[
            ],
            options={
                'verbose_name': 'UnionFieldListFilter',
                'proxy': True,
                'indexes': [],
            },
            bases=('demoapp.demomodel',),
        ),
    ]
